aboutsummaryrefslogtreecommitdiffstats
path: root/Compiler.h
diff options
context:
space:
mode:
Diffstat (limited to 'Compiler.h')
-rw-r--r--Compiler.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/Compiler.h b/Compiler.h
index b6547646..f40339b0 100644
--- a/Compiler.h
+++ b/Compiler.h
@@ -56,10 +56,10 @@ private:
std::function<FunctionDefinition const*(std::string const&)> const& _resolveFunctionOverride,
std::function<ModifierDefinition const*(std::string const&)> const& _resolveModifierOverride);
void appendFunctionSelector(ContractDefinition const& _contract);
- /// Creates code that unpacks the arguments for the given function, from memory if
- /// @a _fromMemory is true, otherwise from call data. @returns the size of the data in bytes.
- unsigned appendCalldataUnpacker(FunctionDefinition const& _function, bool _fromMemory = false);
- void appendReturnValuePacker(FunctionDefinition const& _function);
+ /// Creates code that unpacks the arguments for the given function represented by a vector of TypePointers.
+ /// From memory if @a _fromMemory is true, otherwise from call data. @returns the size of the data in bytes.
+ unsigned appendCalldataUnpacker(TypePointers const& _typeParameters, bool _fromMemory = false);
+ void appendReturnValuePacker(TypePointers const& _typeParameters);
void registerStateVariables(ContractDefinition const& _contract);